=================
tornado-transmute
=================

.. warn:: this is an incomplete project! the owner has migrated to
          aiohttp. Refer to aiohttp for a complete implementation of
          transmute.

          If you are interested in developing this implementation, please contact me via github issue or e-mail

route generation from function signatures in Python, for the tornado framework

-------
Caveats
-------

* In alpha.
* transmute functions must be tornado coroutines.
